.. This file exist only because there's a requirement to have the file
   'contributing.rst' under the folder 'doc/source/contributor' according
   to https://governance.openstack.org/tc/goals/selected/ussuri/project-ptl-and-contrib-docs.html#completion-criteria
   It generally conflicts with the approach taken in Mistral to divide
   all the docs into the three main categories: admin, developer, and user.
   So to avoid duplicating the content of the file we just use a directive
   for inclusion.

.. include:: ../developer/contributor/contributing.rst
